#include "cpu_conf.h"
#include "common.h"


void cpu_clocking_init (unsigned int MValue, unsigned int NValue, unsigned int CCLKDivValue, unsigned int USBCLKDivValue)
{

	PLLCON = 0;				/* Disable PLL, disconnected */
	PLLFEED = 0xaa;
	PLLFEED = 0x55;
    
	SCS |= 0x20;			/* Enable main OSC */
	while( !(SCS & 0x40) );	/* Wait until main OSC is usable */
	
	CLKSRCSEL = 0x01;		/* select main OSC, 12MHz, as the PLL clock source */
	
	PLLCFG = (MValue-1) | ((NValue-1) << 16);
	PLLFEED = 0xaa;
	PLLFEED = 0x55;
	
	PLLCON = 1;				/* Enable PLL, disconnected */
	PLLFEED = 0xaa;
	PLLFEED = 0x55;
	
	CCLKCFG = CCLKDivValue-1;	/* Set clock divider */

	USBCLKCFG = USBCLKDivValue-1;		/* usbclk = 288 MHz/6 = 48 MHz */

	
	while ( ((PLLSTAT & (1 << 26)) == 0) );	/* Check lock bit status */
	    
//	MValue = PLLSTAT & 0x00007FFF;
//	NValue = (PLLSTAT & 0x00FF0000) >> 16;

	
	PLLCON = 3;				/* enable and connect */
	PLLFEED = 0xaa;
	PLLFEED = 0x55;
	while ( ((PLLSTAT & (1 << 25)) == 0) );	/* Check connect bit status */

	return;
}


void pow_init (void)
{

	// 
	PCONP&= ~_BV(PCI2C0)& ~_BV(PCRTC) & ~_BV(PCEMC1) &~_BV(PCAD) &~_BV(PCCAN1) &~_BV(PCCAN2);
	PCONP&= ~_BV(PCI2C1) &~_BV(PCSSP1) & ~_BV(PCSPI)	& ~_BV(PCUART2) &~_BV(PCUART3); 
	PCONP&= ~_BV(PCI2C2) & ~_BV(PCI2S) 	&~_BV(PCSDC) &~_BV(PCGPDMA) &~_BV(PCENET);
	PCONP&= ~_BV(PCUSB) & ~ _BV(PCUART0);
		
	//  
	PCONP|= _BV(PCTIM0) | _BV(PCTIM1) | _BV(PCTIM2) | _BV(PCTIM3) | _BV(PCPWM1) | _BV(PCSSP0);

	return;
}

void cpu_io_init (void)
{

	 	PINSEL0         = 0x00000000;
		PINSEL1         = 0x00000000;
		PINSEL2         = 0x00000000;
		PINSEL3         = 0x00000000;
		PINSEL4         = 0x00000000;

		PINSEL5         = 0x00000000;
		PINSEL6         = 0x00000000;
		PINSEL7         = 0x00000000;
		PINSEL8         = 0x00000000;
		PINSEL9         = 0x00000000;
		PINSEL10        = 0x00000000;
		    
		IODIR0          = 0x00000000;
		IODIR1          = 0x00000000;
		IOSET0          = 0x00000000;
		IOSET1          = 0x00000000;
		   
		FIO0DIR         = 0xffffffff;
		FIO1DIR         = 0xffffffff;
		FIO2DIR         = 0xffffffff;
		FIO3DIR         = 0xffffffff;
		FIO4DIR         = 0xffffffff;
 

		FIO0CLR        = 0xffffffff;
		FIO1CLR         = 0xffffffff;
		FIO2CLR        = 0xffffffff;
		FIO3CLR         = 0xffffffff;
		FIO4CLR         = 0xffffffff;

		VICIntEnClr=0xffffffff;

//-------------------------------------------------------

		FIO0DIR|= _BV(snd);
		FIO0CLR|= _BV(snd);

		FIO1DIR&= ~_BV(adc_m);
		FIO1CLR|= _BV(adc_m);

		FIO1DIR&= ~_BV(diagn);
		FIO1CLR|= _BV(diagn);

		FIO3DIR|= _BV(OC);
		FIO3CLR|= _BV(OC);

		FIO0DIR|= _BV(LCD_BL);
		FIO0SET|= _BV(LCD_BL);

		FIO1DIR|= _BV(vibr);
		FIO1CLR|= _BV(vibr);

		FIO1DIR|= _BV(pow_dn);
		FIO1CLR|= _BV(pow_dn);


		FIO3DIR|= _BV(dmp0);
		FIO3SET|= _BV(dmp0);

		FIO0DIR|= _BV(dmp1);
		FIO0SET|= _BV(dmp1);

		FIO0DIR|= _BV(dmp2);
		FIO0SET|= _BV(dmp2);

		FIO1DIR|= _BV(dmp3);
		FIO1SET|= _BV(dmp3);

		FIO1DIR|= _BV(load);
		FIO1SET|= _BV(load);

		FIO1DIR|= _BV(electr_off);
		FIO1SET|= _BV(electr_off);

		FIO1DIR&= ~_BV(diagn);
		FIO1SET|= _BV(diagn);

		FIO1DIR|= _BV(ONA);
		FIO1CLR|= _BV(ONA);

		// keys
		FIO1DIR&= ~_BV(20);
		FIO1SET|= _BV(20);

		FIO1DIR&= ~_BV(21);
		FIO1SET|= _BV(21);

		FIO1DIR|= _BV(22);
		FIO1SET|= _BV(22);

		FIO2DIR&= ~_BV(11);
		FIO2SET|= _BV(11);




	   return;
}

void PWM_conf (void)
{
	//    
	PINSEL7|=_BV(21); PINSEL7|=_BV(20);	 //Connect PWM1.3 to pin 26

    //           
	PWM1PCR |= _BV(PWMENA3);	  //  PWMENA 3
 	PWM1PCR &=~_BV(PWMSEL3); 	//   
		
// 

	PWM1PR=0x00;   // 


	PWM1MCR|=_BV(1);	//        PWMMR0
	PWM1MCR|=_BV(0);	//       PWMMR0

	PWM1LER|=_BV(0) | _BV(3)  ;	 //  	    0  6

	PWM1TCR|=_BV(0);	   //  

	return;
}

void PWM_set_val (unsigned long freq, unsigned int tau)
{

	PWM1MR0= freq; // 
	PWM1MR3=tau; // 
//	PWM1MR1=tau; // 

	PWM1LER|=_BV(0) | _BV(3)  ;	 //  	    0  6

	PWM1TCR|=_BV(3);	   //  PWM

	return;
}

void TC_conf (void)
{
// ************ **********************************
	PINSEL0|=_BV(19); PINSEL0|=_BV(18);
	
	T2PR = 0x00000000;	 // 
	T2TCR|=_BV(1);	//  

	T2MCR|=_BV(7);	//   MR2
//	T2MCR|=_BV(6);	 // 	 MR2

	T2MCR|=_BV(10);	//   MR3
//	T2MCR|=_BV(9);	 // 	 MR3		

	T2MR3=10;
	T2MR2= 12;					//Set the cycle time

	T2EMR=0;

	T2EMR|= _BV(1);

	T2EMR|=  _BV(11);
	T2EMR|= _BV(10);

	T2TCR&=~_BV(1); T2TCR|=_BV(0);	//   


//***********  ************************
	T0PR = 0x00000001;	 // 
	T0TCR|=_BV(1);	//  

	T0MCR|=_BV(4);	//   MR1
	T0MCR|=_BV(3);	 // 	 MR1		

	T0TCR&=~_BV(1); T0TCR|=_BV(0);	//   

	
//*********** ************************
	T3PR = 0x00000007;	 // 
	T3TCR|=_BV(1);	//  

	T3MCR|=_BV(4);	//   MR1
	T3MCR|=_BV(3);	 // 	 MR1
			
	T3MR1 = 700000;		 // 
			
//	T3TCR&=~_BV(1); T3TCR|=_BV(0);	//   

//**************** ***********************************

	PINSEL3|= _BV(5); PINSEL3|=_BV(4);

	T1PR = 0x00000005;	 // 

	T1TCR |=_BV(1);	//  
	
	T1CCR |= _BV(1)| _BV(0) ;	  //     0

	T1CCR |= _BV(2); //     0

	T1TCR =0x01;	//   
				    
	return;
}

void T0_set_fr (unsigned int f_val)
{
	T0MR1 = 3000000/f_val;	
	return; 
}


